@@ -80,8 +80,18 @@ HTMLWidgets.widget({
           });
           
           chart.on("globalout", function(e){
-            Shiny.onInputChange(el.id + '_global_out' + ":echarts4rParse", e);
+            Shiny.onInputChange(el.id + '_global_out' + ":echarts4rParse", e, {priority: 'event'});
           });
+
+          if(x.hasOwnProperty('zr')){
+            chart.getZr().on("click", function(e){
+              delete e.stop;
+              delete e.topTarget;
+              delete e.target
+              delete e.event.path;
+              Shiny.setInputValue(el.id + '_clicked_zr' + ":echarts4rParse", e);
+            });
+          }
           
           if(x.hasOwnProperty('capture')){
             chart.on(x.capture, function(e){
@@ -197,11 +207,10 @@ HTMLWidgets.widget({
       },
 
       resize: function(width, height) {
+        if(!chart)
+          return;
 
-        if(chart){
-          chart.resize({width: width, height: height});
-        }
-
+        chart.resize({width: width, height: height});
       }
 
     };
